@@ -3,21 +3,21 @@ package JSON;
 
 use strict;
 use Carp ();
-use base qw(Exporter);
+use Exporter;
+BEGIN { @JSON::ISA = 'Exporter' }
+
 @JSON::EXPORT = qw(from_json to_json jsonToObj objToJson encode_json decode_json);
 
 BEGIN {
-    $JSON::VERSION = '2.49_01';
+    $JSON::VERSION = '2.91_01';
     $JSON::DEBUG   = 0 unless (defined $JSON::DEBUG);
     $JSON::DEBUG   = $ENV{ PERL_JSON_DEBUG } if exists $ENV{ PERL_JSON_DEBUG };
 }
 
-my $Module_XS  = 'JSON::XS';
-my $Module_PP  = 'JSON::PP';
-my $Module_bp  = 'JSON::backportPP'; # included in JSON distribution
-my $PP_Version = '2.27008';
-my $XS_Version = '2.27';
-
+my %RequiredVersion = (
+    'JSON::PP' => '2.27203',
+    'JSON::XS' => '2.34',
+);
 
 # XS and PP common methods
 
@@ -32,7 +32,7 @@ my @Properties = qw/
     allow_blessed convert_blessed shrink max_depth max_size allow_unknown
 /;
 
-my @XSOnlyMethods = qw//; # Currently nothing
+my @XSOnlyMethods = qw/allow_tags/; # Currently nothing
 
 my @PPOnlyMethods = qw/
     indent_length sort_by
@@ -42,10 +42,8 @@ my @PPOnlyMethods = qw/
 
 # used in _load_xs and _load_pp ($INSTALL_ONLY is not used currently)
 my $_INSTALL_DONT_DIE  = 1; # When _load_xs fails to load XS, don't die.
-my $_INSTALL_ONLY      = 2; # Don't call _set_methods()
 my $_ALLOW_UNSUPPORTED = 0;
 my $_UNIV_CONV_BLESSED = 0;
-my $_USSING_bpPP       = 0;
 
 
 # Check the environment variable to decide worker module. 
@@ -55,21 +53,32 @@ unless ($JSON::Backend) {
 
     my $backend = exists $ENV{PERL_JSON_BACKEND} ? $ENV{PERL_JSON_BACKEND} : 1;
 
-    if ($backend eq '1' or $backend =~ /JSON::XS\s*,\s*JSON::PP/) {
-        _load_xs($_INSTALL_DONT_DIE) or _load_pp();
+    if ($backend eq '1') {
+        $backend = 'JSON::XS,JSON::PP';
     }
-    elsif ($backend eq '0' or $backend eq 'JSON::PP') {
-        _load_pp();
+    elsif ($backend eq '0') {
+        $backend = 'JSON::PP';
     }
-    elsif ($backend eq '2' or $backend eq 'JSON::XS') {
-        _load_xs();
+    elsif ($backend eq '2') {
+        $backend = 'JSON::XS';
     }
-    elsif ($backend eq 'JSON::backportPP') {
-        $_USSING_bpPP = 1;
-        _load_pp();
-    }
-    else {
-        Carp::croak "The value of environmental variable 'PERL_JSON_BACKEND' is invalid.";
+    $backend =~ s/\s+//g;
+
+    my @backend_modules = split /,/, $backend;
+    while(my $module = shift @backend_modules) {
+        if ($module =~ /JSON::XS/) {
+            _load_xs($module, @backend_modules ? $_INSTALL_DONT_DIE : 0);
+        }
+        elsif ($module =~ /JSON::PP/) {
+            _load_pp($module);
+        }
+        elsif ($module =~ /JSON::backportPP/) {
+            _load_pp($module);
+        }
+        else {
+            Carp::croak "The value of environmental variable 'PERL_JSON_BACKEND' is invalid.";
+        }
+        last if $JSON::Backend;
     }
 }
 
@@ -83,7 +92,7 @@ sub import {
         if ($tag eq '-support_by_pp') {
             if (!$_ALLOW_UNSUPPORTED++) {
                 JSON::Backend::XS
-                    ->support_by_pp(@PPOnlyMethods) if ($JSON::Backend eq $Module_XS);
+                    ->support_by_pp(@PPOnlyMethods) if ($JSON::Backend->is_xs);
             }
             next;
         }
@@ -91,15 +100,22 @@ sub import {
             $no_export++, next;
         }
         elsif ( $tag eq '-convert_blessed_universally' ) {
+            my $org_encode = $JSON::Backend->can('encode');
             eval q|
                 require B;
-                *UNIVERSAL::TO_JSON = sub {
-                    my $b_obj = B::svref_2object( $_[0] );
-                    return    $b_obj->isa('B::HV') ? { %{ $_[0] } }
-                            : $b_obj->isa('B::AV') ? [ @{ $_[0] } ]
-                            : undef
-                            ;
-                }
+                local $^W;
+                no strict 'refs';
+                *{"${JSON::Backend}\::encode"} = sub {
+                    # only works with Perl 5.18+
+                    local *UNIVERSAL::TO_JSON = sub {
+                        my $b_obj = B::svref_2object( $_[0] );
+                        return    $b_obj->isa('B::HV') ? { %{ $_[0] } }
+                                : $b_obj->isa('B::AV') ? [ @{ $_[0] } ]
+                                : undef
+                                ;
+                    };
+                    $org_encode->(@_);
+                };
             | if ( !$_UNIV_CONV_BLESSED++ );
             next;
         }
@@ -136,10 +152,13 @@ sub objToJson {
 # INTERFACES
 
 sub to_json ($@) {
-    if ( ref($_[0]) eq 'JSON' or $_[0] eq 'JSON' ) {
+    if (
+        ref($_[0]) eq 'JSON'
+        or (@_ > 2 and $_[0] eq 'JSON')
+    ) {
         Carp::croak "to_json should not be called as a method.";
     }
-    my $json = new JSON;
+    my $json = JSON->new;
 
     if (@_ == 2 and ref $_[1] eq 'HASH') {
         my $opt  = $_[1];
@@ -156,7 +175,7 @@ sub from_json ($@) {
     if ( ref($_[0]) eq 'JSON' or $_[0] eq 'JSON' ) {
         Carp::croak "from_json should not be called as a method.";
     }
-    my $json = new JSON;
+    my $json = JSON->new;
 
     if (@_ == 2 and ref $_[1] eq 'HASH') {
         my $opt  = $_[1];
@@ -169,6 +188,7 @@ sub from_json ($@) {
 }
 
 
+
 sub true  { $JSON::true  }
 
 sub false { $JSON::false }
@@ -176,7 +196,7 @@ sub false { $JSON::false }
 sub null  { undef; }
 
 
-sub require_xs_version { $XS_Version; }
+sub require_xs_version { $RequiredVersion{'JSON::XS'}; }
 
 sub backend {
     my $proto = shift;
@@ -187,12 +207,12 @@ sub backend {
 
 
 sub is_xs {
-    return $_[0]->module eq $Module_XS;
+    return $_[0]->backend->is_xs;
 }
 
 
 sub is_pp {
-    return not $_[0]->xs;
+    return $_[0]->backend->is_pp;
 }
 
 
@@ -237,92 +257,94 @@ sub property {
 
 # INTERNAL
 
-sub _load_xs {
-    my $opt = shift;
+sub __load_xs {
+    my ($module, $opt) = @_;
 
-    $JSON::DEBUG and Carp::carp "Load $Module_XS.";
-
-    # if called after install module, overload is disable.... why?
-    JSON::Boolean::_overrride_overload($Module_XS);
-    JSON::Boolean::_overrride_overload($Module_PP);
+    $JSON::DEBUG and Carp::carp "Load $module.";
+    my $required_version = $RequiredVersion{$module} || '';
 
     eval qq|
-        use $Module_XS $XS_Version ();
+        use $module $required_version ();
     |;
 
     if ($@) {
         if (defined $opt and $opt & $_INSTALL_DONT_DIE) {
-            $JSON::DEBUG and Carp::carp "Can't load $Module_XS...($@)";
+            $JSON::DEBUG and Carp::carp "Can't load $module...($@)";
             return 0;
         }
         Carp::croak $@;
     }
+    $JSON::BackendModuleXS = $module;
+    return 1;
+}
 
-    unless (defined $opt and $opt & $_INSTALL_ONLY) {
-        _set_module( $JSON::Backend = $Module_XS );
-        my $data = join("", <DATA>); # this code is from Jcode 2.xx.
-        close(DATA);
-        eval $data;
-        JSON::Backend::XS->init;
-    }
+sub _load_xs {
+    my ($module, $opt) = @_;
+    __load_xs($module, $opt) or return;
+
+    my $data = join("", <DATA>); # this code is from Jcode 2.xx.
+    close(DATA);
+    eval $data;
+    JSON::Backend::XS->init($module);
 
     return 1;
 };
 
 
-sub _load_pp {
-    my $opt = shift;
-    my $backend = $_USSING_bpPP ? $Module_bp : $Module_PP;
+sub __load_pp {
+    my ($module, $opt) = @_;
 
-    $JSON::DEBUG and Carp::carp "Load $backend.";
+    $JSON::DEBUG and Carp::carp "Load $module.";
+    my $required_version = $RequiredVersion{$module} || '';
 
-    # if called after install module, overload is disable.... why?
-    JSON::Boolean::_overrride_overload($Module_XS);
-    JSON::Boolean::_overrride_overload($backend);
-
-    if ( $_USSING_bpPP ) {
-        eval qq| require $backend |;
-    }
-    else {
-        eval qq| use $backend $PP_Version () |;
-    }
+    eval qq| use $module $required_version () |;
 
     if ($@) {
-        if ( $backend eq $Module_PP ) {
-            $JSON::DEBUG and Carp::carp "Can't load $Module_PP ($@), so try to load $Module_bp";
-            $_USSING_bpPP++;
-            $backend = $Module_bp;
-            JSON::Boolean::_overrride_overload($backend);
-            local $^W; # if PP installed but invalid version, backportPP redifines methods.
-            eval qq| require $Module_bp |;
+        if ( $module eq 'JSON::PP' ) {
+            $JSON::DEBUG and Carp::carp "Can't load $module ($@), so try to load JSON::backportPP";
+            $module = 'JSON::backportPP';
+            local $^W; # if PP installed but invalid version, backportPP redefines methods.
+            eval qq| require $module |;
         }
         Carp::croak $@ if $@;
     }
+    $JSON::BackendModulePP = $module;
+    return 1;
+}
 
-    unless (defined $opt and $opt & $_INSTALL_ONLY) {
-        _set_module( $JSON::Backend = $Module_PP ); # even if backportPP, set $Backend with 'JSON::PP'
-        JSON::Backend::PP->init;
-    }
+sub _load_pp {
+    my ($module, $opt) = @_;
+    __load_pp($module, $opt);
+
+    JSON::Backend::PP->init($module);
 };
 
+#
+# Helper classes for Backend Module (PP)
+#
 
-sub _set_module {
-    return if defined $JSON::true;
+package JSON::Backend::PP;
 
-    my $module = shift;
+sub init {
+    my ($class, $module) = @_;
+
+    # name may vary, but the module should (always) be a JSON::PP
 
     local $^W;
-    no strict qw(refs);
+    no strict qw(refs); # this routine may be called after JSON::Backend::XS init was called.
+    *{"JSON::decode_json"} = \&{"JSON::PP::decode_json"};
+    *{"JSON::encode_json"} = \&{"JSON::PP::encode_json"};
+    *{"JSON::is_bool"} = \&{"JSON::PP::is_bool"};
 
-    $JSON::true  = ${"$module\::true"};
-    $JSON::false = ${"$module\::false"};
+    $JSON::true  = ${"JSON::PP::true"};
+    $JSON::false = ${"JSON::PP::false"};
 
-    push @JSON::ISA, $module;
-    push @{"$module\::Boolean::ISA"}, qw(JSON::Boolean);
+    push @JSON::Backend::PP::ISA, 'JSON::PP';
+    push @JSON::ISA, $class;
+    $JSON::Backend = $class;
+    $JSON::BackendModule = $module;
 
-    *{"JSON::is_bool"} = \&{"$module\::is_bool"};
-
-    for my $method ($module eq $Module_XS ? @PPOnlyMethods : @XSOnlyMethods) {
+    for my $method (@XSOnlyMethods) {
         *{"JSON::$method"} = sub {
             Carp::carp("$method is not supported in $module.");
             $_[0];
@@ -332,58 +354,8 @@ sub _set_module {
     return 1;
 }
 
-
-
-#
-# JSON Boolean
-#
-
-package JSON::Boolean;
-
-my %Installed;
-
-sub _overrride_overload {
-    return if ($Installed{ $_[0] }++);
-
-    my $boolean = $_[0] . '::Boolean';
-
-    eval sprintf(q|
-        package %s;
-        use overload (
-            '""' => sub { ${$_[0]} == 1 ? 'true' : 'false' },
-            'eq' => sub {
-                my ($obj, $op) = ref ($_[0]) ? ($_[0], $_[1]) : ($_[1], $_[0]);
-                if ($op eq 'true' or $op eq 'false') {
-                    return "$obj" eq 'true' ? 'true' eq $op : 'false' eq $op;
-                }
-                else {
-                    return $obj ? 1 == $op : 0 == $op;
-                }
-            },
-        );
-    |, $boolean);
-
-    if ($@) { Carp::croak $@; }
-
-    return 1;
-}
-
-
-#
-# Helper classes for Backend Module (PP)
-#
-
-package JSON::Backend::PP;
-
-sub init {
-    local $^W;
-    no strict qw(refs); # this routine may be called after JSON::Backend::XS init was called.
-    *{"JSON::decode_json"} = \&{"JSON::PP::decode_json"};
-    *{"JSON::encode_json"} = \&{"JSON::PP::encode_json"};
-    *{"JSON::PP::is_xs"}  = sub { 0 };
-    *{"JSON::PP::is_pp"}  = sub { 1 };
-    return 1;
-}
+sub is_xs { 0 };
+sub is_pp { 1 };
 
 #
 # To save memory, the below lines are read only when XS backend is used.
@@ -401,201 +373,68 @@ __DATA__
 
 package JSON::Backend::XS;
 
-use constant INDENT_LENGTH_FLAG => 15 << 12;
-
-use constant UNSUPPORTED_ENCODE_FLAG => {
-    ESCAPE_SLASH      => 0x00000010,
-    ALLOW_BIGNUM      => 0x00000020,
-    AS_NONBLESSED     => 0x00000040,
-    EXPANDED          => 0x10000000, # for developer's
-};
-
-use constant UNSUPPORTED_DECODE_FLAG => {
-    LOOSE             => 0x00000001,
-    ALLOW_BIGNUM      => 0x00000002,
-    ALLOW_BAREKEY     => 0x00000004,
-    ALLOW_SINGLEQUOTE => 0x00000008,
-    EXPANDED          => 0x20000000, # for developer's
-};
-
-
 sub init {
+    my ($class, $module) = @_;
+
     local $^W;
     no strict qw(refs);
-    *{"JSON::decode_json"} = \&{"JSON::XS::decode_json"};
-    *{"JSON::encode_json"} = \&{"JSON::XS::encode_json"};
-    *{"JSON::XS::is_xs"}  = sub { 1 };
-    *{"JSON::XS::is_pp"}  = sub { 0 };
+    *{"JSON::decode_json"} = \&{"$module\::decode_json"};
+    *{"JSON::encode_json"} = \&{"$module\::encode_json"};
+    *{"JSON::is_bool"} = \&{"$module\::is_bool"};
+
+    $JSON::true  = ${"$module\::true"};
+    $JSON::false = ${"$module\::false"};
+
+    push @JSON::Backend::XS::ISA, $module;
+    push @JSON::ISA, $class;
+    $JSON::Backend = $class;
+    $JSON::BackendModule = $module;
+
+    if ( $module->VERSION < 3 ) {
+        eval 'package JSON::PP::Boolean';
+        push @{"$module\::Boolean::ISA"}, qw(JSON::PP::Boolean);
+    }
+
+    for my $method (@PPOnlyMethods) {
+        *{"JSON::$method"} = sub {
+            Carp::carp("$method is not supported in $module.");
+            $_[0];
+        };
+    }
+
     return 1;
 }
 
+sub is_xs { 1 };
+sub is_pp { 0 };
 
 sub support_by_pp {
     my ($class, @methods) = @_;
 
+    JSON::__load_pp('JSON::PP');
+
     local $^W;
     no strict qw(refs);
 
-    my $JSON_XS_encode_orignal     = \&JSON::XS::encode;
-    my $JSON_XS_decode_orignal     = \&JSON::XS::decode;
-    my $JSON_XS_incr_parse_orignal = \&JSON::XS::incr_parse;
-
-    *JSON::XS::decode     = \&JSON::Backend::XS::Supportable::_decode;
-    *JSON::XS::encode     = \&JSON::Backend::XS::Supportable::_encode;
-    *JSON::XS::incr_parse = \&JSON::Backend::XS::Supportable::_incr_parse;
-
-    *{JSON::XS::_original_decode}     = $JSON_XS_decode_orignal;
-    *{JSON::XS::_original_encode}     = $JSON_XS_encode_orignal;
-    *{JSON::XS::_original_incr_parse} = $JSON_XS_incr_parse_orignal;
-
-    push @JSON::Backend::XS::Supportable::ISA, 'JSON';
-
-    my $pkg = 'JSON::Backend::XS::Supportable';
-
-    *{JSON::new} = sub {
-        my $proto = new JSON::XS; $$proto = 0;
-        bless  $proto, $pkg;
-    };
-
-
     for my $method (@methods) {
-        my $flag = uc($method);
-        my $type |= (UNSUPPORTED_ENCODE_FLAG->{$flag} || 0);
-           $type |= (UNSUPPORTED_DECODE_FLAG->{$flag} || 0);
-
-        next unless($type);
-
-        $pkg->_make_unsupported_method($method => $type);
+        my $pp_method = JSON::PP->can($method) or next;
+        *{"JSON::$method"} = sub {
+            if (!$_[0]->isa('JSON::PP')) {
+                my $xs_self = $_[0];
+                my $pp_self = JSON::PP->new;
+                for (@Properties) {
+                     my $getter = "get_$_";
+                    $pp_self->$_($xs_self->$getter);
+                }
+                $_[0] = $pp_self;
+            }
+            $pp_method->(@_);
+        };
     }
 
-    push @{"JSON::XS::Boolean::ISA"}, qw(JSON::PP::Boolean);
-    push @{"JSON::PP::Boolean::ISA"}, qw(JSON::Boolean);
-
     $JSON::DEBUG and Carp::carp("set -support_by_pp mode.");
-
-    return 1;
 }
 
-
-
-
-#
-# Helper classes for XS
-#
-
-package JSON::Backend::XS::Supportable;
-
-$Carp::Internal{'JSON::Backend::XS::Supportable'} = 1;
-
-sub _make_unsupported_method {
-    my ($pkg, $method, $type) = @_;
-
-    local $^W;
-    no strict qw(refs);
-
-    *{"$pkg\::$method"} = sub {
-        local $^W;
-        if (defined $_[1] ? $_[1] : 1) {
-            ${$_[0]} |= $type;
-        }
-        else {
-            ${$_[0]} &= ~$type;
-        }
-        $_[0];
-    };
-
-    *{"$pkg\::get_$method"} = sub {
-        ${$_[0]} & $type ? 1 : '';
-    };
-
-}
-
-
-sub _set_for_pp {
-    JSON::_load_pp( $_INSTALL_ONLY );
-
-    my $type  = shift;
-    my $pp    = new JSON::PP;
-    my $prop = $_[0]->property;
-
-    for my $name (keys %$prop) {
-        $pp->$name( $prop->{$name} ? $prop->{$name} : 0 );
-    }
-
-    my $unsupported = $type eq 'encode' ? JSON::Backend::XS::UNSUPPORTED_ENCODE_FLAG
-                                        : JSON::Backend::XS::UNSUPPORTED_DECODE_FLAG;
-    my $flags       = ${$_[0]} || 0;
-
-    for my $name (keys %$unsupported) {
-        next if ($name eq 'EXPANDED'); # for developer's
-        my $enable = ($flags & $unsupported->{$name}) ? 1 : 0;
-        my $method = lc $name;
-        $pp->$method($enable);
-    }
-
-    $pp->indent_length( $_[0]->get_indent_length );
-
-    return $pp;
-}
-
-sub _encode { # using with PP encod
-    if (${$_[0]}) {
-        _set_for_pp('encode' => @_)->encode($_[1]);
-    }
-    else {
-        $_[0]->_original_encode( $_[1] );
-    }
-}
-
-
-sub _decode { # if unsupported-flag is set, use PP
-    if (${$_[0]}) {
-        _set_for_pp('decode' => @_)->decode($_[1]);
-    }
-    else {
-        $_[0]->_original_decode( $_[1] );
-    }
-}
-
-
-sub decode_prefix { # if unsupported-flag is set, use PP
-    _set_for_pp('decode' => @_)->decode_prefix($_[1]);
-}
-
-
-sub _incr_parse {
-    if (${$_[0]}) {
-        _set_for_pp('decode' => @_)->incr_parse($_[1]);
-    }
-    else {
-        $_[0]->_original_incr_parse( $_[1] );
-    }
-}
-
-
-sub get_indent_length {
-    ${$_[0]} << 4 >> 16;
-}
-
-
-sub indent_length {
-    my $length = $_[1];
-
-    if (!defined $length or $length > 15 or $length < 0) {
-        Carp::carp "The acceptable range of indent_length() is 0 to 15.";
-    }
-    else {
-        local $^W;
-        $length <<= 12;
-        ${$_[0]} &= ~ JSON::Backend::XS::INDENT_LENGTH_FLAG;
-        ${$_[0]} |= $length;
-        *JSON::XS::encode = \&JSON::Backend::XS::Supportable::_encode;
-    }
-
-    $_[0];
-}
-
-
 1;
 __END__
 
@@ -637,28 +476,62 @@ JSON - JSON (JavaScript Object Notation) encoder/decoder
  
 =head1 VERSION
 
-    2.50
+    2.91_01
 
-This version is compatible with JSON::XS B<2.27> and later.
+This version is compatible with JSON::XS B<2.34> and later.
+(Not yet compatble to JSON::XS B<3.0x>.)
 
 
-=head1 PLAN
+=head1 NOTE
 
-JSON::PP was inculded in JSON distribution (CPAN module).
-It comes to be a perl core module in Perl 5.14.
-And JSON::PP well be split away it.
+JSON::PP was earlier included in the C<JSON> distribution, but
+has since Perl 5.14 been a core module. For this reason,
+L<JSON::PP> was removed from the JSON distribution and can now
+be found also in the Perl5 repository at
 
-This developer-versoin is for the preparation.
+=over
 
-    * JSON distribution will inculde yet another JSON::PP modules.
-      They are JSNO::backportPP. So JSON.pm should work as it did at all!
+=item * L<http://perl5.git.perl.org/perl.git>
+
+=back
+
+(The newest JSON::PP version still exists in CPAN.)
+
+Instead, the C<JSON> distribution will include JSON::backportPP
+for backwards compatibility. JSON.pm should thus work as it did
+before.
 
 =head1 DESCRIPTION
 
+ *************************** CAUTION **************************************
+ *                                                                        *
+ * INCOMPATIBLE CHANGE (JSON::XS version 2.90)                            *
+ *                                                                        *
+ * JSON.pm had patched JSON::XS::Boolean and JSON::PP::Boolean internally *
+ * on loading time for making these modules inherit JSON::Boolean.        *
+ * But since JSON::XS v3.0 it use Types::Serialiser as boolean class.     *
+ * Then now JSON.pm breaks boolean classe overload features and           *
+ * -support_by_pp if JSON::XS v3.0 or later is installed.                 *
+ *                                                                        *
+ * JSON::true and JSON::false returned JSON::Boolean objects.             *
+ * For workaround, they return JSON::PP::Boolean objects in this version. *
+ *                                                                        *
+ *     isa_ok(JSON::true, 'JSON::PP::Boolean');                           *
+ *                                                                        *
+ * And it discards a feature:                                             *
+ *                                                                        *
+ *     ok(JSON::true eq 'true');                                          *
+ *                                                                        *
+ * In other word, JSON::PP::Boolean overload numeric only.                *
+ *                                                                        *
+ *     ok( JSON::true == 1 );                                             *
+ *                                                                        *
+ **************************************************************************
+
  ************************** CAUTION ********************************
  * This is 'JSON module version 2' and there are many differences  *
  * to version 1.xx                                                 *
- * Please check your applications useing old version.              *
+ * Please check your applications using old version.              *
  *   See to 'INCOMPATIBLE CHANGES TO OLD VERSION'                  *
  *******************************************************************
 
@@ -698,7 +571,7 @@ how and when it does so, and even documents what "correct" means.
 Even though there are limitations, this feature is available since Perl version 5.6.
 
 JSON::XS requires Perl 5.8.2 (but works correctly in 5.8.8 or later), so in older versions
-C<JSON> sholud call JSON::PP as the backend which can be used since Perl 5.005.
+C<JSON> should call JSON::PP as the backend which can be used since Perl 5.005.
 
 With Perl 5.8.x JSON::PP works, but from 5.8.0 to 5.8.2, because of a Perl side problem,
 JSON::PP works slower in the versions. And in 5.005, the Unicode handling is not available.
@@ -729,7 +602,7 @@ See to L<JSON::XS/FEATURES> and L<JSON::PP/FEATURES>.
 
 This module returns a JSON::XS object itself if available.
 Compared to other JSON modules and other serialisers such as Storable,
-JSON::XS usually compares favourably in terms of speed, too.
+JSON::XS usually compares favorably in terms of speed, too.
 
 If not available, C<JSON> returns a JSON::PP object instead of JSON::XS and
 it is very slow as pure-Perl.
@@ -793,7 +666,7 @@ Takes a hash reference as the second.
 
 So,
 
-   $json_text = encode_json($perl_scalar, {utf8 => 1, pretty => 1})
+   $json_text = to_json($perl_scalar, {utf8 => 1, pretty => 1})
 
 equivalent to:
 
@@ -811,7 +684,7 @@ to parse it, returning the resulting reference.
 
 This function call is functionally identical to:
 
-    $perl_scalar = JSON->decode($json_text)
+    $perl_scalar = JSON->new->decode($json_text)
 
 Takes a hash reference as the second.
 
@@ -855,7 +728,7 @@ Perl.
 
 =head1 HOW DO I DECODE A DATA FROM OUTER AND ENCODE TO OUTER
 
-This section supposes that your perl vresion is 5.8 or later.
+This section supposes that your perl version is 5.8 or later.
 
 If you know a JSON text from an outer world - a network, a file content, and so on,
 is encoded in UTF-8, you should use C<decode_json> or C<JSON> module object
@@ -937,7 +810,7 @@ See to L<Encode>, L<perluniintro>.
 
 =head2 new
 
-    $json = new JSON
+    $json = JSON->new
 
 Returns a new C<JSON> object inherited from either JSON::XS or JSON::PP
 that can be used to de/encode JSON strings.
@@ -1040,10 +913,10 @@ space length.
 
 If C<$enable> is true (or missing), then the C<encode> method will use a multiline
 format as output, putting every array member or object/hash key-value pair
-into its own line, identing them properly.
+into its own line, identifying them properly.
 
 If C<$enable> is false, no newlines or indenting will be produced, and the
-resulting JSON text is guarenteed not to contain any C<newlines>.
+resulting JSON text is guaranteed not to contain any C<newlines>.
 
 This setting has no effect when decoding JSON texts.
 
@@ -1394,7 +1267,7 @@ crashing. (JSON::XS)
 
 With JSON::PP as the backend, when a large value (100 or more) was set and
 it de/encodes a deep nested object/text, it may raise a warning
-'Deep recursion on subroutin' at the perl runtime phase.
+'Deep recursion on subroutine' at the perl runtime phase.
 
 See L<JSON::XS/SECURITY CONSIDERATIONS> for more info on why this is useful.
 
@@ -1448,7 +1321,7 @@ silently stop parsing there and return the number of characters consumed
 so far.
 
    JSON->new->decode_prefix ("[1] the tail")
-   => ([], 3)
+   => ([1], 3)
 
 See to L<JSON::XS/OBJECT-ORIENTED INTERFACE>
 
@@ -1473,7 +1346,7 @@ Sets the property with a given boolean value.
 
     $json = $json->property($property_name => $boolean);
 
-With no argumnt, it returns all the above properties as a hash reference.
+With no argument, it returns all the above properties as a hash reference.
 
     $flag_hashref = $json->property();
 
@@ -1491,7 +1364,7 @@ to see if a full JSON object is available, but is much more efficient
 The backend module will only attempt to parse the JSON text once it is sure it
 has enough text to get a decisive result, using a very simple but
 truly incremental parser. This means that it sometimes won't stop as
-early as the full parser, for example, it doesn't detect parenthese
+early as the full parser, for example, it doesn't detect parenthesis
 mismatches. The only thing it guarantees is that it starts decoding as
 soon as a syntactically valid JSON text has been seen. This means you need
 to set resource limits (e.g. C<max_size>) to ensure the parser will stop
@@ -1522,7 +1395,7 @@ If the method is called in scalar context, then it will try to extract
 exactly I<one> JSON object. If that is successful, it will return this
 object, otherwise it will return C<undef>. If there is a parse error,
 this method will croak just as C<decode> would do (one can then use
-C<incr_skip> to skip the errornous part). This is the most common way of
+C<incr_skip> to skip the erroneous part). This is the most common way of
 using the method.
 
 And finally, in list context, it will try to extract as many objects
@@ -1578,7 +1451,7 @@ unchanged, to skip the text parsed so far and to reset the parse state.
 This completely resets the incremental parser, that is, after this call,
 it will be as if the parser had never parsed anything.
 
-This is useful if you want ot repeatedly parse JSON objects and want to
+This is useful if you want to repeatedly parse JSON objects and want to
 ignore any trailing data, which means you have to reset the parser after
 each successful decode.
 
@@ -1591,14 +1464,14 @@ The below methods are JSON::PP own methods, so when C<JSON> works
 with JSON::PP (i.e. the created object is a JSON::PP object), available.
 See to L<JSON::PP/JSON::PP OWN METHODS> in detail.
 
-If you use C<JSON> with additonal C<-support_by_pp>, some methods
+If you use C<JSON> with additional C<-support_by_pp>, some methods
 are available even with JSON::XS. See to L<USE PP FEATURES EVEN THOUGH XS BACKEND>.
 
-   BEING { $ENV{PERL_JSON_BACKEND} = 'JSON::XS' }
+   BEGIN { $ENV{PERL_JSON_BACKEND} = 'JSON::XS' }
    
    use JSON -support_by_pp;
    
-   my $json = new JSON;
+   my $json = JSON->new;
    $json->allow_nonref->escape_slash->encode("/");
 
    # functional interfaces too.
@@ -1646,7 +1519,7 @@ If C<$enable> is true (or missing), then C<decode> will convert
 the big integer Perl cannot handle as integer into a L<Math::BigInt>
 object and convert a floating number (any) into a L<Math::BigFloat>.
 
-On the contary, C<encode> converts C<Math::BigInt> objects and C<Math::BigFloat>
+On the contrary, C<encode> converts C<Math::BigInt> objects and C<Math::BigFloat>
 objects into JSON numbers with C<allow_blessed> enable.
 
    $json->allow_nonref->allow_blessed->allow_bignum;
@@ -1654,14 +1527,14 @@ objects into JSON numbers with C<allow_blessed> enable.
    print $json->encode($bigfloat);
    # => 2.000000000000000000000000001
 
-See to L<MAPPING> aboout the conversion of JSON number.
+See to L<MAPPING> about the conversion of JSON number.
 
 =head2 loose
 
     $json = $json->loose([$enable])
 
 The unescaped [\x00-\x1f\x22\x2f\x5c] strings are invalid in JSON strings
-and the module doesn't allow to C<decode> to these (except for \x2f).
+and the module doesn't allow one to C<decode> to these (except for \x2f).
 If C<$enable> is true (or missing), then C<decode>  will accept these
 unescaped strings.
 
@@ -1749,7 +1622,7 @@ it as an integer value. If that fails, it will try to represent it as
 a numeric (floating point) value if that is possible without loss of
 precision. Otherwise it will preserve the number as a string value (in
 which case you lose roundtripping ability, as the JSON number will be
-re-encoded toa JSON string).
+re-encoded to a JSON string).
 
 Numbers containing a fractional or exponential part will always be
 represented as numeric (floating point) values, possibly at a loss of
@@ -1759,7 +1632,7 @@ the JSON number will still be re-encoded as a JSON number).
 Note that precision is not accuracy - binary floating point values cannot
 represent most decimal fractions exactly, and when converting from and to
 floating point, C<JSON> only guarantees precision up to but not including
-the leats significant bit.
+the least significant bit.
 
 If the backend is JSON::PP and C<allow_bignum> is enable, the big integers 
 and the numeric can be optionally converted into L<Math::BigInt> and
@@ -1769,18 +1642,12 @@ L<Math::BigFloat> objects.
 
 These JSON atoms become C<JSON::true> and C<JSON::false>,
 respectively. They are overloaded to act almost exactly like the numbers
-C<1> and C<0>. You can check wether a scalar is a JSON boolean by using
+C<1> and C<0>. You can check whether a scalar is a JSON boolean by using
 the C<JSON::is_bool> function.
 
-If C<JSON::true> and C<JSON::false> are used as strings or compared as strings,
-they represent as C<true> and C<false> respectively.
-
-   print JSON::true . "\n";
-    => true
    print JSON::true + 1;
     => 1
 
-   ok(JSON::true eq 'true');
    ok(JSON::true eq  '1');
    ok(JSON::true == 1);
 
@@ -1791,7 +1658,7 @@ C<JSON> will install these missing overloading features to the backend modules.
 
 A JSON null atom becomes C<undef> in Perl.
 
-C<JSON::null> returns C<unddef>.
+C<JSON::null> returns C<undef>.
 
 =back
 
@@ -1811,7 +1678,7 @@ in hash keys (or JSON objects), they will usually be encoded in a
 pseudo-random order that can change between runs of the same program but
 stays generally the same within a single run of a program. C<JSON>
 optionally sort the hash keys (determined by the I<canonical> flag), so
-the same datastructure will serialise to the same JSON text (given same
+the same data structure will serialise to the same JSON text (given same
 settings and version of JSON::XS), but this incurs a runtime overhead
 and is only rarely useful, e.g. when you want to compare some JSON text
 against another for equality.
@@ -1886,7 +1753,7 @@ You can force the type to be a number by numifying it:
 
    my $x = "3"; # some variable containing a string
    $x += 0;     # numify it, ensuring it will be dumped as a number
-   $x *= 1;     # same thing, the choise is yours.
+   $x *= 1;     # same thing, the choice is yours.
 
 You can not currently force the type in other, less obscure, ways.
 
@@ -1922,7 +1789,7 @@ When you use C<JSON>, C<JSON> tries to C<use> JSON::XS. If this call failed, it
 C<uses> JSON::PP. The required JSON::XS version is I<2.2> or later.
 
 The C<JSON> constructor method returns an object inherited from the backend module,
-and JSON::XS object is a blessed scaler reference while JSON::PP is a blessed hash
+and JSON::XS object is a blessed scalar reference while JSON::PP is a blessed hash
 reference.
 
 So, your program should not depend on the backend module, especially
@@ -1944,7 +1811,7 @@ To check the backend module, there are some methods - C<backend>, C<is_pp> and C
   $json->is_pp; # 0 or 1
 
 
-If you set an enviornment variable C<PERL_JSON_BACKEND>, The calling action will be changed.
+If you set an environment variable C<PERL_JSON_BACKEND>, the calling action will be changed.
 
 =over
 
@@ -1961,6 +1828,12 @@ otherwise use JSON::PP.
 
 Always use compiled JSON::XS, die if it isn't properly compiled & installed.
 
+=item PERL_JSON_BACKEND = 'JSON::backportPP'
+
+Always use JSON::backportPP.
+JSON::backportPP is JSON::PP back port module.
+C<JSON> includes JSON::backportPP instead of JSON::PP.
+
 =back
 
 These ideas come from L<DBI::PurePerl> mechanism.
@@ -1975,16 +1848,16 @@ In future, it may be able to specify another module.
 =head1 USE PP FEATURES EVEN THOUGH XS BACKEND
 
 Many methods are available with either JSON::XS or JSON::PP and
-when the backend module is JSON::XS, if any JSON::PP specific (i.e. JSON::XS unspported)
+when the backend module is JSON::XS, if any JSON::PP specific (i.e. JSON::XS unsupported)
 method is called, it will C<warn> and be noop.
 
 But If you C<use> C<JSON> passing the optional string C<-support_by_pp>,
-it makes a part of those unupported methods available.
+it makes a part of those unsupported methods available.
 This feature is achieved by using JSON::PP in C<de/encode>.
 
    BEGIN { $ENV{PERL_JSON_BACKEND} = 2 } # with JSON::XS
    use JSON -support_by_pp;
-   my $json = new JSON;
+   my $json = JSON->new;
    $json->allow_nonref->escape_slash->encode("/");
 
 At this time, the returned object is a C<JSON::Backend::XS::Supportable>
@@ -2110,7 +1983,7 @@ You can set parameters instead;
 
 =item $JSON::Pretty, $JSON::Indent, $JSON::Delimiter
 
-If C<indent> is enable, that menas C<$JSON::Pretty> flag set. And
+If C<indent> is enable, that means C<$JSON::Pretty> flag set. And
 C<$JSON::Delimiter> was substituted by C<space_before> and C<space_after>.
 In conclusion:
 
@@ -2204,10 +2077,10 @@ Disable. See to L<MAPPING>.
 =item $JSON::SelfConvert
 
 This option was deleted.
-Instead of it, if a givien blessed object has the C<TO_JSON> method,
+Instead of it, if a given blessed object has the C<TO_JSON> method,
 C<TO_JSON> will be executed with C<convert_blessed>.
 
-  $json->convert_blessed->encode($bleesed_hashref_or_arrayref)
+  $json->convert_blessed->encode($blessed_hashref_or_arrayref)
   # if need, call allow_blessed
 
 Note that it was C<toJson> in old version, but now not C<toJson> but C<TO_JSON>.
@@ -2246,12 +2119,12 @@ Makamaka Hannyaharamitu, E<lt>makamaka[at]cpan.orgE<gt>
 
 JSON::XS was written by  Marc Lehmann <schmorp[at]schmorp.de>
 
-The relese of this new version owes to the courtesy of Marc Lehmann.
+The release of this new version owes to the courtesy of Marc Lehmann.
 
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2005-2010 by Makamaka Hannyaharamitu
+Copyright 2005-2013 by Makamaka Hannyaharamitu
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
